@@ -7,6 +7,7 @@ import uuid
 from django.db.models.query import QuerySet
 
 from isc_common import setAttr
+from isc_common.common import uuid4
 from list.listCalendarEvent import LinkedList
 
 logger = logging.getLogger(__name__)
@@ -97,11 +98,11 @@ class CalendarEventLinkedList(LinkedList):
                     if shift.item.endDate > relax.item.startDate:
                         if shift.item.endDate > relax.item.endDate:
                             # self.print('self:')
-                            self.replace(y, shift.item.copy(id=str(uuid.uuid4()), endDate=relax.item.startDate))
+                            self.replace(y, shift.item.copy(id=uuid4(), endDate=relax.item.startDate))
                             # self.print('self:')
-                            self.insert(y + 1, relax.item.copy(id=str(uuid.uuid4()), ))
+                            self.insert(y + 1, relax.item.copy(id=uuid4(), ))
                             # self.print('self:')
-                            self.insert(y + 2, shift.item.copy(id=str(uuid.uuid4()), startDate=relax.item.endDate))
+                            self.insert(y + 2, shift.item.copy(id=uuid4(), startDate=relax.item.endDate))
                             # self.print('self:')
                             break
                         else:
