@@ -8,6 +8,7 @@ from django.db import transaction
 
 from crypto.models.upload_file import DSResponse_UploadFile
 from isc_common.auth.models.user import User
+from isc_common.common import uuid4
 from isc_common.common.functions import Common
 from isc_common.datetime import StrToDate
 from isc_common.dropzone import Dz
@@ -40,7 +41,7 @@ class DSResponse__Messages_UploadFile(DSResponse_UploadFile):
         setattr(self.dz_dictionary, 'stored_file_name', self.dz_dictionary.dzuuid)
         setattr(self.dz_dictionary, 'file_size', self.dz_dictionary.dztotalfilesize)
         setattr(self.dz_dictionary, 'file_mime_type', self.file.content_type)
-        setattr(self.dz_dictionary, 'guid', str(uuid.uuid4()).upper())
+        setattr(self.dz_dictionary, 'guid', uuid4())
 
         self.handle_uploaded_file()
 
